DropboxAccount class

Dropbox 계정 정보를 나타내는 클래스입니다.

Constructors

DropboxAccount({required String accountId, required String email, required String name, String? profilePhotoUrl, required bool disabled, String? country})
DropboxAccount.fromJson(Map<String, dynamic> json)
factory

Properties

accountId String
final
country String?
final
disabled bool
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
profilePhotoUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited