DropboxFolder class

Dropbox 폴더를 나타내는 클래스입니다.

Constructors

DropboxFolder({required String id, required String name, required String pathLower, required String pathDisplay})
DropboxFolder.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
pathDisplay String
final
pathLower String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited