DropboxFolderContents class

Dropbox 폴더 내용을 나타내는 클래스입니다.

Constructors

DropboxFolderContents({required List<DropboxFile> entries, String? cursor, required bool hasMore})
DropboxFolderContents.fromJson(Map<String, dynamic> json)
factory

Properties

cursor String?
final
entries List<DropboxFile>
final
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited