Microsoft class

Constructors

Microsoft({required String clientId, String? clientSecret, required String redirectUri, required List<String>? scopes})

Properties

authEndpoint String
finalinherited
clientId String
finalinherited
clientSecret String?
finalinherited
codeVerifier String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
redirectUri String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>?
finalinherited
tokenEndpoint String
finalinherited

Methods

exchangeCode(String? code) Future<String?>
inherited
login() Future<OAuth2Token?>
inherited
loginFromDesktop() Future<OAuth2Token?>
inherited
loginFromMobile() Future<OAuth2Token?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken(String? refreshToken) Future<OAuth2Token?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited