OAuth2Account class

Constructors

OAuth2Account({OAuth2TokenStorage? tokenStorage, required String appPrefix})

Properties

appPrefix String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addProvider(OAuth2Provider provider) → void
allAccounts({String service = ""}) Future<List<(String, String)>>
any({String service = ""}) Future<OAuth2Token?>
createClient(OAuth2Token token) Future<OAuth2RestClient>
deleteAccount(String service, String userName) Future<void>
forceRelogin(OAuth2Token expiredToken) Future<OAuth2Token?>
getProvider(String nameOrIss) → OAuth2Provider?
keyFor(String service, String userName) String
loadAccount(String service, String userName) Future<OAuth2Token?>
newLogin(String service) Future<OAuth2Token?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken(OAuth2Token expiredToken) Future<OAuth2Token?>
saveAccount(String service, String userName, OAuth2Token token) Future<void>
toString() String
A string representation of this object.
inherited
tryAutoLogin(String service, String userName) Future<OAuth2Token?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tokenPrefix → const String