OAuth2MultiBody class

Implemented types

Constructors

OAuth2MultiBody({required List<OAuth2FormData> parts, required String type, String? boundary})
OAuth2MultiBody.formData(List<OAuth2FormData> parts)
factory
OAuth2MultiBody.related(OAuth2JsonBody meta, OAuth2FileBody file)
factory

Properties

boundary String
final
contentLength int?
no setteroverride
contentType String?
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
parts List<OAuth2FormData>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

buildHeader(OAuth2FormData part) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() List<int>
override
toStream() Stream<List<int>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited