DropboxFile class
Dropbox 파일/폴더 메타데이터를 나타내는 클래스입니다.
Constructors
Properties
- clientModified → DateTime?
-
final
- contentHash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isDownloadable → bool?
-
final
- isFile → bool
-
tag가 null이면 파일로 가정합니다.
no setter
- isFolder → bool
-
no setter
- name → String
-
final
- pathDisplay → String
-
final
- pathLower → String
-
final
- rev → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverModified → DateTime?
-
final
- size → int?
-
final
- tag → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited