DropboxRestApi class
- Implemented types
Constructors
- DropboxRestApi(OAuth2RestClient client)
Properties
- client → OAuth2RestClient
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copy(
String fromPath, String toPath) → Future< void> -
파일이나 폴더를 복사합니다.
override
-
createFolder(
String path) → Future< DropboxFolder> -
폴더를 생성합니다.
override
-
delete(
String path) → Future< void> -
파일이나 폴더를 삭제합니다.
override
-
download(
String path) → Future< Stream< List< >int> > -
파일을 다운로드합니다.
override
-
getCurrentAccount(
) → Future< DropboxAccount> -
현재 사용자의 계정 정보를 가져옵니다.
override
-
listFolder(
String path, {int limit = 2000}) → Future< DropboxFolderContents> -
폴더 내용을 조회합니다.
override
-
listFolderContinue(
String cursor) → Future< DropboxFolderContents> -
이전 list_folder 호출의 결과를 계속 가져옵니다.
override
-
move(
String fromPath, String toPath) → Future< void> -
파일이나 폴더를 이동합니다.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upload(
String path, Stream< List< dataStream, {String mode = 'add', bool autorename = true}) → Future<int> >DropboxFile> -
파일을 업로드합니다.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited