Properties
-
cancelFuture
→ Future<
void> -
토큰이 취소되면 완료되는 Future
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
토큰이 취소되었는지 여부
no setter
- reason → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
String? reason) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
throwIfCancelled(
) → void - 토큰이 이미 취소되었다면 예외를 발생시킵니다
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited